<?php

namespace Litecms\ManageIP\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\ManageIP\Models\ManageIp;

class ManageIpPolicy
{

    /**
     * Determine if the given user can view the manage_ip.
     *
     * @param UserPolicy $user
     * @param ManageIp $manage_ip
     *
     * @return bool
     */
    public function view(UserPolicy $user, ManageIp $manage_ip)
    {
        if ($user->canDo('manage_i_p.manage_ip.view') && $user->isAdmin()) {
            return true;
        }

        return $manage_ip->user_id == user_id() && $manage_ip->user_type == user_type();
    }

    /**
     * Determine if the given user can create a manage_ip.
     *
     * @param UserPolicy $user
     * @param ManageIp $manage_ip
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('manage_i_p.manage_ip.create');
    }

    /**
     * Determine if the given user can update the given manage_ip.
     *
     * @param UserPolicy $user
     * @param ManageIp $manage_ip
     *
     * @return bool
     */
    public function update(UserPolicy $user, ManageIp $manage_ip)
    {
        if ($user->canDo('manage_i_p.manage_ip.edit') && $user->isAdmin()) {
            return true;
        }

        return $manage_ip->user_id == user_id() && $manage_ip->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given manage_ip.
     *
     * @param UserPolicy $user
     * @param ManageIp $manage_ip
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, ManageIp $manage_ip)
    {
        return $manage_ip->user_id == user_id() && $manage_ip->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given manage_ip.
     *
     * @param UserPolicy $user
     * @param ManageIp $manage_ip
     *
     * @return bool
     */
    public function verify(UserPolicy $user, ManageIp $manage_ip)
    {
        if ($user->canDo('manage_i_p.manage_ip.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given manage_ip.
     *
     * @param UserPolicy $user
     * @param ManageIp $manage_ip
     *
     * @return bool
     */
    public function approve(UserPolicy $user, ManageIp $manage_ip)
    {
        if ($user->canDo('manage_i_p.manage_ip.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
