<?php

namespace Litecms\ManageIP\Providers;

use Illuminate\Support\ServiceProvider;

class ManageIPServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'manage_i_p');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'manage_i_p');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('litecms.manage_i_p', function ($app) {
            return $this->app->make('Litecms\ManageIP\ManageIP');
        });

                // Bind ManageIp to repository
        $this->app->bind(
            'Litecms\ManageIP\Interfaces\ManageIpRepositoryInterface',
            \Litecms\ManageIP\Repositories\Eloquent\ManageIpRepository::class
        );

        $this->app->register(\Litecms\ManageIP\Providers\AuthServiceProvider::class);
                $this->app->register(\Litecms\ManageIP\Providers\EventServiceProvider::class);
        
        $this->app->register(\Litecms\ManageIP\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.manage_i_p'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/manage_i_p.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/manage_i_p')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/manage_i_p')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
